@@ -2,7 +2,7 @@ import sys
 import argparse
 from flashcards.card_set import Set, learn_set
 
-if __name__ == "__main__":
+def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("-s", "--shuffle", help="shuffle order of flashcards in the set", action="store_true")
     parser.add_argument("-r", "--reverse", help="reverse answering, answer with term rather than definition", action="store_true")
@@ -11,4 +11,7 @@ if __name__ == "__main__":
     args = parser.parse_args()
 
     card_set = Set.load_from_csv(args.path)
-    learn_set(card_set, shuffle=args.shuffle, answer_reverse=args.reverse)
\ No newline at end of file
+    learn_set(card_set, shuffle=args.shuffle, answer_reverse=args.reverse)
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
